==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/dd4/roadveh_8h.js <==
var roadveh_8h =
[
    [ "RoadVehicle", "d2/dd0/structRoadVehicle.html", "d2/dd0/structRoadVehicle" ],
    [ "FOR_ALL_ROADVEHICLES", "d4/dd4/roadveh_8h.html#a4b227e65ff09a022d921e00874bbd3c4", null ],
    [ "RoadVehicleStates", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641", [
      [ "RVSB_IN_DEPOT", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641adfb86ed2861a208c8c535248e01c7f17", null ],
      [ "RVSB_WORMHOLE", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641af224ea58e3b7fbb31a749a31fa8b315e", null ],
      [ "RVS_USING_SECOND_BAY", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a68dbe66ff7e3a3ce9407192a605e5e1a", null ],
      [ "RVS_ENTERED_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a3223351e01b08d803d8c8c83ad18a5a1", null ],
      [ "RVS_DRIVE_SIDE", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641aff70523b08585919e88024f4eeee6469", null ],
      [ "RVS_IN_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a984d3e6f44f0e2a1f8a1e91b9e727c67", null ],
      [ "RVS_IN_DT_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a7653046a8923746ac3c2c890289e2f10", null ],
      [ "RVSB_IN_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a350e615f8cb01905eddd61b93a869bb2", null ],
      [ "RVSB_IN_ROAD_STOP_END", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a9c691bd9427bc94b590955ba5bcaddbb", null ],
      [ "RVSB_IN_DT_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a10fa1a85b8101bc3982648b9a9a23ac9", null ],
      [ "RVSB_IN_DT_ROAD_STOP_END", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641ad130627f57a1dcb33a43b946486916e4", null ],
      [ "RVSB_DRIVE_SIDE", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a7ec20c9a29b66b49c281158a6344e60a", null ],
      [ "RVSB_TRACKDIR_MASK", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a7710c119084a6da4da29ad2a2d4cec1f", null ],
      [ "RVSB_ROAD_STOP_TRACKDIR_MASK", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a71906fd824876d5d3db590f06f4131ce", null ]
    ] ],
    [ "GetRoadVehSpriteSize", "d4/dd4/roadveh_8h.html#a9adba7e7b3d8998e74ff3a61abfb105f", null ],
    [ "RoadVehUpdateCache", "d4/dd4/roadveh_8h.html#abd9018a7a570f7e9c57397e9d816e6e5", null ],
    [ "RDE_NEXT_TILE", "d4/dd4/roadveh_8h.html#ac9c0cb463871d5360c008574fad94b94", null ],
    [ "RDE_TURNED", "d4/dd4/roadveh_8h.html#a429527988fc80d6455208d79af23f062", null ],
    [ "RV_OVERTAKE_TIMEOUT", "d4/dd4/roadveh_8h.html#a1a90bef62cbd162267c09872d3fb5163", null ],
    [ "RVC_DEFAULT_START_FRAME", "d4/dd4/roadveh_8h.html#aa278f480f6812ea6440729ed35fa3b47", null ],
    [ "RVC_DEPOT_START_FRAME", "d4/dd4/roadveh_8h.html#ac0f5d7a7d8d86357de7841313f059cda", null ],
    [ "RVC_DEPOT_STOP_FRAME", "d4/dd4/roadveh_8h.html#a9941a479a398a34587b68b8e06fce9f4", null ],
    [ "RVC_DRIVE_THROUGH_STOP_FRAME", "d4/dd4/roadveh_8h.html#a611c7d98af7f7d4a3e2e7b3ce009533c", null ],
    [ "RVC_START_FRAME_AFTER_LONG_TRAM", "d4/dd4/roadveh_8h.html#a023b946a80a86ace500d95f834670110", null ],
    [ "RVC_TURN_AROUND_START_FRAME", "d4/dd4/roadveh_8h.html#ac36b6be2e585aed8266d124e6f778766", null ],
    [ "RVC_TURN_AROUND_START_FRAME_SHORT_TRAM", "d4/dd4/roadveh_8h.html#aafdd381b384926dd596e789e922c0461", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/dd4/roadveh_8h.js <==
var roadveh_8h =
[
    [ "RoadVehPathCache", "d7/db9/structRoadVehPathCache.html", "d7/db9/structRoadVehPathCache" ],
    [ "RoadVehicle", "d2/dd0/structRoadVehicle.html", "d2/dd0/structRoadVehicle" ],
    [ "RoadVehicleStates", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641", [
      [ "RVSB_IN_DEPOT", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641adfb86ed2861a208c8c535248e01c7f17", null ],
      [ "RVSB_WORMHOLE", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641af224ea58e3b7fbb31a749a31fa8b315e", null ],
      [ "RVS_USING_SECOND_BAY", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a68dbe66ff7e3a3ce9407192a605e5e1a", null ],
      [ "RVS_ENTERED_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a3223351e01b08d803d8c8c83ad18a5a1", null ],
      [ "RVS_DRIVE_SIDE", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641aff70523b08585919e88024f4eeee6469", null ],
      [ "RVS_IN_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a984d3e6f44f0e2a1f8a1e91b9e727c67", null ],
      [ "RVS_IN_DT_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a7653046a8923746ac3c2c890289e2f10", null ],
      [ "RVSB_IN_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a350e615f8cb01905eddd61b93a869bb2", null ],
      [ "RVSB_IN_ROAD_STOP_END", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a9c691bd9427bc94b590955ba5bcaddbb", null ],
      [ "RVSB_IN_DT_ROAD_STOP", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a10fa1a85b8101bc3982648b9a9a23ac9", null ],
      [ "RVSB_IN_DT_ROAD_STOP_END", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641ad130627f57a1dcb33a43b946486916e4", null ],
      [ "RVSB_DRIVE_SIDE", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a7ec20c9a29b66b49c281158a6344e60a", null ],
      [ "RVSB_TRACKDIR_MASK", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a7710c119084a6da4da29ad2a2d4cec1f", null ],
      [ "RVSB_ROAD_STOP_TRACKDIR_MASK", "d4/dd4/roadveh_8h.html#a8fb3892810ac6086e8077442c47e6641a71906fd824876d5d3db590f06f4131ce", null ]
    ] ],
    [ "GetRoadVehSpriteSize", "d4/dd4/roadveh_8h.html#a9adba7e7b3d8998e74ff3a61abfb105f", null ],
    [ "RoadVehUpdateCache", "d4/dd4/roadveh_8h.html#abd9018a7a570f7e9c57397e9d816e6e5", null ],
    [ "RDE_NEXT_TILE", "d4/dd4/roadveh_8h.html#ac9c0cb463871d5360c008574fad94b94", null ],
    [ "RDE_TURNED", "d4/dd4/roadveh_8h.html#a429527988fc80d6455208d79af23f062", null ],
    [ "RV_OVERTAKE_TIMEOUT", "d4/dd4/roadveh_8h.html#a1a90bef62cbd162267c09872d3fb5163", null ],
    [ "RVC_DEFAULT_START_FRAME", "d4/dd4/roadveh_8h.html#aa278f480f6812ea6440729ed35fa3b47", null ],
    [ "RVC_DEPOT_START_FRAME", "d4/dd4/roadveh_8h.html#ac0f5d7a7d8d86357de7841313f059cda", null ],
    [ "RVC_DEPOT_STOP_FRAME", "d4/dd4/roadveh_8h.html#a9941a479a398a34587b68b8e06fce9f4", null ],
    [ "RVC_DRIVE_THROUGH_STOP_FRAME", "d4/dd4/roadveh_8h.html#a611c7d98af7f7d4a3e2e7b3ce009533c", null ],
    [ "RVC_START_FRAME_AFTER_LONG_TRAM", "d4/dd4/roadveh_8h.html#a023b946a80a86ace500d95f834670110", null ],
    [ "RVC_TURN_AROUND_START_FRAME", "d4/dd4/roadveh_8h.html#ac36b6be2e585aed8266d124e6f778766", null ],
    [ "RVC_TURN_AROUND_START_FRAME_SHORT_TRAM", "d4/dd4/roadveh_8h.html#aafdd381b384926dd596e789e922c0461", null ]
];
